<?php

namespace Shopbydedi\Payment;

use Shopbydedi\Model\CardModel;
use Shopbydedi\Model\SaveCard;

/**
 * Class PayplugConfig
 * @package Shopbydedi\Payment
 */
class PayplugConfig
{
    /**
     * @var string
     */
    protected $privateKey;

    /**
     * @var string
     */
    protected $publicKey;

    /**
     * @var SaveCard
     */
    protected $model;

    /**
     * PayplugConfig constructor.
     *
     * @param array $config
     */
    public function __construct(array $config = array())
    {
        if (isset($config['private_key'])) {
            $this->setPrivateKey($config['private_key']);
        }
        if (isset($config['public_key'])) {
            $this->setPublicKey($config['public_key']);
        }
        $this->setModel(isset($config['card_model']) ? $config['card_model'] : new CardModel());
    }

    /**
     * Check if the config is valid or not
     *
     * @return bool
     */
    public function isValid()
    {
        $privateKey = $this->getPrivateKey();
        $publicKey = $this->getPublicKey();
        return (
            !empty($privateKey)
            || !empty($publicKey)
        );
    }

    /**
     * @return SaveCard
     */
    public function getModel()
    {
        return $this->model;
    }

    /**
     * @param mixed $model
     */
    public function setModel($model)
    {
        $this->model = $model;
    }

    /**
     * @return string
     */
    public function getPublicKey()
    {
        return $this->publicKey;
    }

    /**
     * @param string $publicKey
     */
    public function setPublicKey($publicKey)
    {
        $this->publicKey = $publicKey;
    }

    /**
     * @return string
     */
    public function getPrivateKey()
    {
        return $this->privateKey;
    }

    /**
     * @param string $privateKey
     */
    public function setPrivateKey($privateKey)
    {
        $this->privateKey = $privateKey;
    }
}
